﻿-- Database: Bilsalg

-- Eksempeldata for tabell Bilsalg inneholder ca. 220 000 rader
-- og foreligger kun som CSV-fil. For å bygge databasen kan man
-- først kjøre dette skriptet, og deretter importere CSV-filen
-- (se lenke til forklaring på import øverst på nettsiden "Datasett").


-- Sletter tabellene

-- For å få et skript som kan kjøres flere ganger:

-- DROP TABLE Bilsalg;
-- DROP TABLE Bilmodell;
-- DROP TABLE Kommune;


-- MySQL
-- For å få et skript som kan kjøres flere ganger,
-- og som fungerer enten tabellen(e) finnes eller ikke:

-- DROP TABLE IF EXISTS Bilsalg;
-- DROP TABLE IF EXISTS Bilmodell;
-- DROP TABLE IF EXISTS Kommune;



-- Oppretter tabellene

CREATE TABLE Kommune
(
  KommuneNr   CHAR(4),
  Kommunenavn VARCHAR(50) NOT NULL,
  CONSTRAINT  KommunePN PRIMARY KEY ( KommuneNr )
);

CREATE TABLE Bilmodell
(
  Bilmerke   VARCHAR(50),
  Bilmodell  VARCHAR(50),
  Gruppe     CHAR(15),
  AntallHK   SMALLINT NOT NULL,
  CONSTRAINT BilmodellPN PRIMARY KEY (Bilmerke, Bilmodell )
);

CREATE TABLE Bilsalg
(
  Bilmerke   VARCHAR(50),
  Bilmodell  VARCHAR(50),
  KommuneNr  CHAR(4),
  År         SMALLINT,
  Måned      SMALLINT,
  Antall     SMALLINT NOT NULL,
  CONSTRAINT BilsalgPN PRIMARY KEY
    (Bilmerke, Bilmodell, KommuneNr, År, Måned ),
  CONSTRAINT BilsalgKommuneFN
    FOREIGN KEY (KommuneNr) REFERENCES Kommune (KommuneNr),
  CONSTRAINT BilsalgBilmodellFN FOREIGN KEY (Bilmerke, Bilmodell)
    REFERENCES Bilmodell (Bilmerke, Bilmodell)
);



-- Setter inn eksempeldata

INSERT INTO Bilmodell(Bilmerke, Bilmodell, Gruppe, AntallHK) VALUES
  ('Toyota',     'Avensis',     'personbil', 130),
  ('Toyota',     'Auris',       'personbil', 105),
  ('Ford',       'Focus',       'personbil', 120),
  ('Opel',       'Astra',       'personbil', 101),
  ('Scania',     'KEB',         'buss',      450),
  ('Volkswagen', 'Transporter', 'varebil',   140),
  ('Scania',     '124',         'lastebil',  360);


INSERT INTO Kommune (KommuneNr, Kommunenavn) VALUES
('0101', 'HALDEN'),
('0104', 'MOSS'),
('0105', 'SARPSBORG'),
('0106', 'FREDRIKSTAD'),
('0111', 'HVALER'),
('0118', 'AREMARK'),
('0119', 'MARKER'),
('0121', 'RØMSKOG'),
('0122', 'TRØGSTAD'),
('0123', 'SPYDEBERG'),
('0124', 'ASKIM'),
('0125', 'EIDSBERG'),
('0127', 'SKIPTVET'),
('0128', 'RAKKESTAD'),
('0135', 'RÅDE'),
('0136', 'RYGGE'),
('0137', 'VÅLER'),
('0138', 'HOBØL'),
('0211', 'VESTBY'),
('0213', 'SKI'),
('0214', 'ÅS'),
('0215', 'FROGN'),
('0216', 'NESODDEN'),
('0217', 'OPPEGÅRD'),
('0219', 'BÆRUM'),
('0220', 'ASKER'),
('0221', 'AURSKOG-HØLAND'),
('0226', 'SØRUM'),
('0227', 'FET'),
('0228', 'RÆLINGEN'),
('0229', 'ENEBAKK'),
('0230', 'LØRENSKOG'),
('0231', 'SKEDSMO'),
('0233', 'NITTEDAL'),
('0234', 'GJERDRUM'),
('0235', 'ULLENSAKER'),
('0236', 'NES'),
('0237', 'EIDSVOLL'),
('0238', 'NANNESTAD'),
('0239', 'HURDAL'),
('0301', 'OSLO'),
('0402', 'KONGSVINGER'),
('0403', 'HAMAR'),
('0412', 'RINGSAKER'),
('0415', 'LØTEN'),
('0417', 'STANGE'),
('0418', 'NORD-ODAL'),
('0419', 'SØR-ODAL'),
('0420', 'EIDSKOG'),
('0423', 'GRUE'),
('0425', 'ÅSNES'),
('0426', 'VÅLER'),
('0427', 'ELVERUM'),
('0428', 'TRYSIL'),
('0429', 'ÅMOT'),
('0430', 'STOR-ELVDAL'),
('0432', 'RENDALEN'),
('0434', 'ENGERDAL'),
('0436', 'TOLGA'),
('0437', 'TYNSET'),
('0438', 'ALVDAL'),
('0439', 'FOLLDAL'),
('0441', 'OS (HEDMARK)'),
('0501', 'LILLEHAMMER'),
('0502', 'GJØVIK'),
('0511', 'DOVRE'),
('0512', 'LESJA'),
('0513', 'SKJÅK'),
('0514', 'LOM'),
('0515', 'VÅGÅ'),
('0516', 'NORD-FRON'),
('0517', 'SEL'),
('0519', 'SØR-FRON'),
('0520', 'RINGEBU'),
('0521', 'ØYER'),
('0522', 'GAUSDAL'),
('0528', 'ØSTRE TOTEN'),
('0529', 'VESTRE TOTEN'),
('0532', 'JEVNAKER'),
('0533', 'LUNNER'),
('0534', 'GRAN'),
('0536', 'SØNDRE LAND'),
('0538', 'NORDRE LAND'),
('0540', 'SØR-AURDAL'),
('0541', 'ETNEDAL'),
('0542', 'NORD-AURDAL'),
('0543', 'VESTRE SLIDRE'),
('0544', 'ØYSTRE SLIDRE'),
('0545', 'VANG'),
('0602', 'DRAMMEN'),
('0604', 'KONGSBERG'),
('0605', 'RINGERIKE'),
('0612', 'HOLE'),
('0615', 'FLÅ'),
('0616', 'NES'),
('0617', 'GOL'),
('0618', 'HEMSEDAL'),
('0619', 'ÅL'),
('0620', 'HOL'),
('0621', 'SIGDAL'),
('0622', 'KRØDSHERAD'),
('0623', 'MODUM'),
('0624', 'ØVRE EIKER'),
('0625', 'NEDRE EIKER'),
('0626', 'LIER'),
('0627', 'RØYKEN'),
('0628', 'HURUM'),
('0631', 'FLESBERG'),
('0632', 'ROLLAG'),
('0633', 'NORE OG UVDAL'),
('0701', 'HORTEN'),
('0702', 'HOLMESTRAND'),
('0704', 'TØNSBERG'),
('0706', 'SANDEFJORD'),
('0709', 'LARVIK'),
('0711', 'SVELVIK'),
('0713', 'SANDE (V.)'),
('0714', 'HOF'),
('0716', 'RE'),
('0719', 'ANDEBU'),
('0720', 'STOKKE'),
('0722', 'NØTTERØY'),
('0723', 'TJØME'),
('0728', 'LARDAL'),
('0805', 'PORSGRUNN'),
('0806', 'SKIEN'),
('0807', 'NOTODDEN'),
('0811', 'SILJAN'),
('0814', 'BAMBLE'),
('0815', 'KRAGERØ'),
('0817', 'DRANGEDAL'),
('0819', 'NOME'),
('0821', 'BØ (TEL.)'),
('0822', 'SAUHERAD'),
('0826', 'TINN'),
('0827', 'HJARTDAL'),
('0828', 'SELJORD'),
('0829', 'KVITESEID'),
('0830', 'NISSEDAL'),
('0831', 'FYRESDAL'),
('0833', 'TOKKE'),
('0834', 'VINJE'),
('0901', 'RISØR'),
('0904', 'GRIMSTAD'),
('0906', 'ARENDAL'),
('0911', 'GJERSTAD'),
('0912', 'VEGÅRSHEI'),
('0914', 'TVEDESTRAND'),
('0919', 'FROLAND'),
('0926', 'LILLESAND'),
('0928', 'BIRKENES'),
('0929', 'ÅMLI'),
('0935', 'IVELAND'),
('0937', 'EVJE OG HORNNES'),
('0938', 'BYGLAND'),
('0940', 'VALLE'),
('0941', 'BYKLE'),
('1001', 'KRISTIANSAND'),
('1002', 'MANDAL'),
('1003', 'FARSUND'),
('1004', 'FLEKKEFJORD'),
('1014', 'VENNESLA'),
('1017', 'SONGDALEN'),
('1018', 'SØGNE'),
('1021', 'MARNARDAL'),
('1026', 'ÅSERAL'),
('1027', 'AUDNEDAL'),
('1029', 'LINDESNES'),
('1032', 'LYNGDAL'),
('1034', 'HÆGEBOSTAD'),
('1037', 'KVINESDAL'),
('1046', 'SIRDAL'),
('1101', 'EIGERSUND'),
('1102', 'SANDNES'),
('1103', 'STAVANGER'),
('1106', 'HAUGESUND'),
('1111', 'SOKNDAL'),
('1112', 'LUND'),
('1114', 'BJERKREIM'),
('1119', 'HÅ'),
('1120', 'KLEPP'),
('1121', 'TIME'),
('1122', 'GJESDAL'),
('1124', 'SOLA'),
('1127', 'RANDABERG'),
('1129', 'FORSAND'),
('1130', 'STRAND'),
('1133', 'HJELMELAND'),
('1134', 'SULDAL'),
('1135', 'SAUDA'),
('1141', 'FINNØY'),
('1142', 'RENNESØY'),
('1144', 'KVITSØY'),
('1145', 'BOKN'),
('1146', 'TYSVÆR'),
('1149', 'KARMØY'),
('1151', 'UTSIRA'),
('1160', 'VINDAFJORD'),
('1201', 'BERGEN'),
('1211', 'ETNE'),
('1216', 'SVEIO'),
('1219', 'BØMLO'),
('1221', 'STORD'),
('1222', 'FITJAR'),
('1223', 'TYSNES'),
('1224', 'KVINNHERAD'),
('1227', 'JONDAL'),
('1228', 'ODDA'),
('1231', 'ULLENSVANG'),
('1232', 'EIDFJORD'),
('1233', 'ULVIK'),
('1234', 'GRANVIN'),
('1235', 'VOSS'),
('1238', 'KVAM'),
('1241', 'FUSA'),
('1242', 'SAMNANGER'),
('1243', 'OS (HORDALAND)'),
('1244', 'AUSTEVOLL'),
('1245', 'SUND'),
('1246', 'FJELL'),
('1247', 'ASKØY'),
('1251', 'VAKSDAL'),
('1252', 'MODALEN'),
('1253', 'OSTERØY'),
('1256', 'MELAND'),
('1259', 'ØYGARDEN'),
('1260', 'RADØY'),
('1263', 'LINDÅS'),
('1264', 'AUSTRHEIM'),
('1265', 'FEDJE'),
('1266', 'MASFJORDEN'),
('1401', 'FLORA'),
('1411', 'GULEN'),
('1412', 'SOLUND'),
('1413', 'HYLLESTAD'),
('1416', 'HØYANGER'),
('1417', 'VIK'),
('1418', 'BALESTRAND'),
('1419', 'LEIKANGER'),
('1420', 'SOGNDAL'),
('1421', 'AURLAND'),
('1422', 'LÆRDAL'),
('1424', 'ÅRDAL'),
('1426', 'LUSTER'),
('1428', 'ASKVOLL'),
('1429', 'FJALER'),
('1430', 'GAULAR'),
('1431', 'JØLSTER'),
('1432', 'FØRDE'),
('1433', 'NAUSTDAL'),
('1438', 'BREMANGER'),
('1439', 'VÅGSØY'),
('1441', 'SELJE'),
('1443', 'EID'),
('1444', 'HORNINDAL'),
('1445', 'GLOPPEN'),
('1449', 'STRYN'),
('1502', 'MOLDE'),
('1504', 'ÅLESUND'),
('1505', 'KRISTIANSUND'),
('1511', 'VANYLVEN'),
('1514', 'SANDE (M.R.)'),
('1515', 'HERØY (M.R.)'),
('1516', 'ULSTEIN'),
('1517', 'HAREID'),
('1519', 'VOLDA'),
('1520', 'ØRSTA'),
('1523', 'ØRSKOG'),
('1524', 'NORDDAL'),
('1525', 'STRANDA'),
('1526', 'STORDAL'),
('1528', 'SYKKYLVEN'),
('1529', 'SKODJE'),
('1531', 'SULA'),
('1532', 'GISKE'),
('1534', 'HARAM'),
('1535', 'VESTNES'),
('1539', 'RAUMA'),
('1543', 'NESSET'),
('1545', 'MIDSUND'),
('1546', 'SANDØY'),
('1547', 'AUKRA'),
('1548', 'FRÆNA'),
('1551', 'EIDE'),
('1554', 'AVERØY'),
('1557', 'GJEMNES'),
('1560', 'TINGVOLL'),
('1563', 'SUNNDAL'),
('1566', 'SURNADAL'),
('1567', 'RINDAL'),
('1571', 'HALSA'),
('1573', 'SMØLA'),
('1576', 'AURE'),
('1601', 'TRONDHEIM'),
('1612', 'HEMNE'),
('1613', 'SNILLFJORD'),
('1617', 'HITRA'),
('1620', 'FRØYA'),
('1621', 'ØRLAND'),
('1622', 'AGDENES'),
('1624', 'RISSA'),
('1627', 'BJUGN'),
('1630', 'ÅFJORD'),
('1632', 'ROAN'),
('1633', 'OSEN'),
('1634', 'OPPDAL'),
('1635', 'RENNEBU'),
('1636', 'MELDAL'),
('1638', 'ORKDAL'),
('1640', 'RØROS'),
('1644', 'HOLTÅLEN'),
('1648', 'MIDTRE GAULDAL'),
('1653', 'MELHUS'),
('1657', 'SKAUN'),
('1662', 'KLÆBU'),
('1663', 'MALVIK'),
('1664', 'SELBU'),
('1665', 'TYDAL'),
('1702', 'STEINKJER'),
('1703', 'NAMSOS'),
('1711', 'MERÅKER'),
('1714', 'STJØRDAL'),
('1717', 'FROSTA'),
('1718', 'LEKSVIK'),
('1719', 'LEVANGER'),
('1721', 'VERDAL'),
('1724', 'VERRAN'),
('1725', 'NAMDALSEID'),
('1736', 'SNÅSA'),
('1738', 'LIERNE'),
('1739', 'RØYRVIK'),
('1740', 'NAMSSKOGAN'),
('1742', 'GRONG'),
('1743', 'HØYLANDET'),
('1744', 'OVERHALLA'),
('1748', 'FOSNES'),
('1749', 'FLATANGER'),
('1750', 'VIKNA'),
('1751', 'NÆRØY'),
('1755', 'LEKA'),
('1756', 'INDERØY'),
('1804', 'BODØ'),
('1805', 'NARVIK'),
('1811', 'BINDAL'),
('1812', 'SØMNA'),
('1813', 'BRØNNØY'),
('1815', 'VEGA'),
('1816', 'VEVELSTAD'),
('1818', 'HERØY (N.)'),
('1820', 'ALSTAHAUG'),
('1822', 'LEIRFJORD'),
('1824', 'VEFSN'),
('1825', 'GRANE'),
('1826', 'HATTFJELLDAL'),
('1827', 'DØNNA'),
('1828', 'NESNA'),
('1832', 'HEMNES'),
('1833', 'RANA'),
('1834', 'LURØY'),
('1835', 'TRÆNA'),
('1836', 'RØDØY'),
('1837', 'MELØY'),
('1838', 'GILDESKÅL'),
('1839', 'BEIARN'),
('1840', 'SALTDAL'),
('1841', 'FAUSKE'),
('1845', 'SØRFOLD'),
('1848', 'STEIGEN'),
('1849', 'HAMARØY'),
('1850', 'TYSFJORD'),
('1851', 'LØDINGEN'),
('1852', 'TJELDSUND'),
('1853', 'EVENES'),
('1854', 'BALLANGEN'),
('1856', 'RØST'),
('1857', 'VÆRØY'),
('1859', 'FLAKSTAD'),
('1860', 'VESTVÅGØY'),
('1865', 'VÅGAN'),
('1866', 'HADSEL'),
('1867', 'BØ (N.)'),
('1868', 'ØKSNES'),
('1870', 'SORTLAND'),
('1871', 'ANDØY'),
('1874', 'MOSKENES'),
('1902', 'TROMSØ'),
('1903', 'HARSTAD'),
('1911', 'KVÆFJORD'),
('1913', 'SKÅNLAND'),
('1917', 'IBESTAD'),
('1919', 'GRATANGEN'),
('1920', 'LAVANGEN'),
('1922', 'BARDU'),
('1923', 'SALANGEN'),
('1924', 'MÅLSELV'),
('1925', 'SØRREISA'),
('1926', 'DYRØY'),
('1927', 'TRANØY'),
('1928', 'TORSKEN'),
('1929', 'BERG'),
('1931', 'LENVIK'),
('1933', 'BALSFJORD'),
('1936', 'KARLSØY'),
('1938', 'LYNGEN'),
('1939', 'STORFJORD'),
('1940', 'GÁIVUOTNA KÅFJORD'),
('1941', 'SKJERVØY'),
('1942', 'NORDREISA'),
('1943', 'KVÆNANGEN'),
('2002', 'VARDØ'),
('2003', 'VADSØ'),
('2004', 'HAMMERFEST'),
('2011', 'GUOVDAGEAIDNU KAUTOKEINO'),
('2012', 'ALTA'),
('2014', 'LOPPA'),
('2015', 'HASVIK'),
('2017', 'KVALSUND'),
('2018', 'MÅSØY'),
('2019', 'NORDKAPP'),
('2020', 'PORSANGER PORSÁNGU PORSANKI'),
('2021', 'KARASJOHKA KARASJOK'),
('2022', 'LEBESBY'),
('2023', 'GAMVIK'),
('2024', 'BERLEVÅG'),
('2025', 'DEATNU TANA'),
('2027', 'UNJARGGA NESSEBY'),
('2028', 'BÅTSFJORD'),
('2030', 'SØR-VARANGER'),
('2111', 'SPITSBERGEN'),
('2121', 'BJØRNØYA'),
('2131', 'HOPEN'),
('2211', 'JAN MAYEN');
