﻿-- Database: Forsikring


-- Sletter tabellene

-- For å få et skript som kan kjøres flere ganger:

-- DROP TABLE Skadesak;
-- DROP TABLE Forsikring;
-- DROP TABLE Kunde;


-- MySQL
-- For å få et skript som kan kjøres flere ganger,
-- og som fungerer enten tabellen(e) finnes eller ikke:

-- DROP TABLE IF EXISTS Skadesak;
-- DROP TABLE IF EXISTS Forsikring;
-- DROP TABLE IF EXISTS Kunde;



-- Oppretter tabellene

CREATE TABLE Kunde
(
  KundeNr    INT AUTO_INCREMENT,
  FDato      DATE,
  Fornavn    VARCHAR(30),
  Etternavn  VARCHAR(50),
  CONSTRAINT KundePK PRIMARY KEY (KundeNr)
);

CREATE TABLE Forsikring
(
  ForsNr     INT AUTO_INCREMENT,
  KundeNr    INT NOT NULL,
  RegNr      CHAR(7) UNIQUE NOT NULL,
  RegAar     INT NOT NULL,
  KmPrAar    INT NOT NULL,
  ForsType   VARCHAR(10) NOT NULL,
  Bonus      INT,
  AarsPremie DECIMAL(8, 2),
  CONSTRAINT ForsikringPK PRIMARY KEY (ForsNr),
  CONSTRAINT ForsikringKundeFK FOREIGN KEY (KundeNr) REFERENCES Kunde(KundeNr)
);

CREATE TABLE Skadesak
(
  SaksNr      INT AUTO_INCREMENT,
  ForsNr      INT NOT NULL,
  RegDato     DATE,
  SkadeType   VARCHAR(30),
  CONSTRAINT SkadesakPK PRIMARY KEY (SaksNr),
  CONSTRAINT SkadesakForsikringFK FOREIGN KEY (ForsNr) REFERENCES Forsikring(ForsNr)
);



-- Setter inn eksempeldata

INSERT INTO
  Kunde(FDato, Fornavn, Etternavn)
VALUES
  ('1992-07-17', 'Ola',    'Hansen'),
  ('1995-11-04', 'Kari',   'Mo'),
  ('1974-02-28', 'Anette', 'Lien');

INSERT INTO
  Forsikring(KundeNr, RegNr, RegAar, KmPrAar, ForsType, Bonus, AarsPremie)
VALUES
  (1, 'LY12345', 2016, 22000, 'Kasko',    50, 4500.00),
  (1, 'AD33445', 2001, 11000, 'Ansvar',   70, 2300.00),
  (2, 'KZ99887', 2014, 18000, 'Kasko',    20, 7800.00),
  (3, 'PN29298', 2014, 25000, 'Delkasko', 50, 5200.00);
  
INSERT INTO
  Skadesak(ForsNr, RegDato, SkadeType)
VALUES
  (1, '2018-02-10', 'Kollisjon'),
  (2, '2018-12-16', 'Brannskade'),
  (2, '2019-07-30', 'Kollisjon'),
  (2, '2019-10-01', 'Tyveri'),
  (3, '2019-10-30', 'Glassrute');
